@@ -1,5 +1,7 @@
-UFA_locate_regex <- function(string, pattern) {
-  UFAgreg <- gregexpr(pattern, string)[[1]]
+UFA_locate_regex <- function(string, pattern, ignore.case = FALSE, perl = FALSE,
+                             fixed = FALSE, useBytes = FALSE) {
+  ##
+  UFAgreg <- gregexpr(pattern, string, ignore.case, perl, fixed, useBytes)[[1]]
   if (UFAgreg[1] > 0) {
     UFAgreg_lengthchar <- attributes(UFAgreg)$match.length
     #
@@ -7,7 +9,7 @@ UFA_locate_regex <- function(string, pattern) {
       c(UFAgreg[i], (UFAgreg[i] + UFAgreg_lengthchar[i] - 1))
     }))
   } else {
-    loc_mat <- matrix(c(NA, NA), nrow = 1)
+    loc_mat <- NULL
   }
   #
   return(loc_mat)
